Learn R Programming

Rrelperm (version 0.1.0)

kr3p_Baker: Generate a matrix of three-phase relative permeability data for the water-gas-oil system using Baker's linear model

Description

The 'kr3p_Baker()' creates a table of three-phase oil relative permeability data for water, gas, and oil saturation values between zero and one. This model reads the water, and gas saturation values in the three-phase region as water, and gas saturation inputs into two-phase relative permeability models

Usage

kr3p_Baker(
  SWCON,
  SWCRIT,
  SOIRW,
  SORW,
  SOIRG,
  SORG,
  SGCON,
  SGCRIT,
  KRWIRO,
  KROCW,
  KRGCL,
  NW,
  NOW,
  NG,
  NOG,
  NP
)

Arguments

SWCON

connate water saturation, fraction

SWCRIT

critical water saturation, fraction

SOIRW

irreducible oil saturation, fraction

SORW

residual oil saturation, fraction

SOIRG

irreducible oil saturation, fraction

SORG

residual oil saturation, fraction

SGCON

connate gas saturation, fraction

SGCRIT

critical gas saturation, fraction

KRWIRO

water relative permeability at irreducible oil

KROCW

oil relative permeability at connate water

KRGCL

gas relative permeability at connate liquid

NW

exponent term for calculating krw

NOW

exponent term for calculating krow

NG

exponent term for calculating krg

NOG

exponent term for calculating krog

NP

number of saturation points in the two-phase relative permeability tables, the maximum acceptable value is 501. The number of data points in the three-phase relative permeability table is (0.5 * NP * (NP + 1))

Value

A matrix with water saturation, gas saturation, oil saturation, and oil relative permeability values, respectively.

References

Baker1988Rrelperm

Examples

Run this code
# NOT RUN {
rel_perm_wgo <- kr3p_Baker(0.15, 0.2, 0.15, 0.15, 0.2, 0.2, 0.05, 0.05, 0.4,
1, 0.3, 3, 2, 4, 2.5, 101)

# }

Run the code above in your browser using DataLab