kr3p_StoneII_So: Generate a matrix of three-phase relative permeability data for the water-gas-oil system using the modified Stone II model
Description
The 'kr3p_StoneII_So()' creates a table of three-phase oil relative permeability data for water, gas, and oil saturation values between zero and one. This model reads the oil saturation in the three-phase region as oil saturation input into two-phase relative permeability models
number of saturation points in the two-phase relative permeability tables, the maximum acceptable value is 501. The number of data points in the three-phase relative permeability table is (0.5 * NP * (NP + 1))
Value
A matrix with water saturation, gas saturation, oil saturation, and oil relative permeability values, respectively.