powered by
The 'kr2p_ow()' creates a table of two-phase water and oil relative permeability data for water and oil saturation values between zero and one.
kr2p_ow(SWCON, SWCRIT, SOIRW, SORW, KRWIRO, KROCW, NW, NOW, NP)
connate water saturation, fraction
critical water saturation, fraction
irreducible oil saturation, fraction
residual oil saturation, fraction
water relative permeability at irreducible oil
oil relative permeability at connate water
exponent term for calculating krw
exponent term for calculating krow
number of saturation points in the table, the maximum acceptable value is 501
A matrix with water saturation, oil saturation, water relative permeability, and oil relative permeability values, respectively
Brooks1964Rrelperm
# NOT RUN { rel_perm_wo <- kr2p_ow(0.15, 0.2, 0.15, 0.15, 0.4, 1, 3, 2, 101) # }
Run the code above in your browser using DataLab